import { IsString } from 'class-validator';
import { Authorized, JsonController, Post, QueryParam } from 'routing-controllers';
import { OpenAPI } from 'routing-controllers-openapi';
import { Mailer } from '../Mailer';

/**
 * The mail controller handels all endpoints concerning Mail sending.
 */
@JsonController()
@Authorized()
@OpenAPI({ security: [{ "AuthToken": [] }] })
export class MailController {
    private mailer: Mailer = new Mailer();
    private initialized: boolean = false;

    @Post('/reset')
    @OpenAPI({ description: "Sends reset mails", parameters: [{ in: "query", name: "locale", schema: { type: "string", enum: ["de", "en"] } }] })
    async sendReset(@QueryParam("locale") locale: locales) {
        if (!this.initialized) {
            await this.mailer.init();
            this.initialized = true;
        }
        try {
            this.mailer.sendResetMail("todo", "lelele", locale?.toString())
        } catch (error) {
            throw error;
        }
        return new SuccessResponse(locale);
    }

    @Post('/test')
    @OpenAPI({ description: "Sends test mails", parameters: [{ in: "query", name: "locale", schema: { type: "string", enum: ["de", "en"] } }] })
    async sendTest(@QueryParam("locale") locale: locales) {
        if (!this.initialized) {
            await this.mailer.init();
            this.initialized = true;
        }
        try {
            this.mailer.sendTestMail(locale?.toString())
        } catch (error) {
            console.log(error)
            throw error;
        }
        return new SuccessResponse(locale);
    }
}

/**
 * Simple success response class to make everyone happy :)
 */
export class SuccessResponse {

    @IsString()
    success: boolean = true;

    @IsString()
    message: string = "Sent!"

    @IsString()
    locale: locales;

    constructor(locale?: locales) {
        this.locale = locale || locales.en;
    }
}

export enum locales {
    de = "de",
    en = "en"
}